<h1> !!!This repo is under development and NOT stable!!! </h1>

# napari
[![License](https://img.shields.io/pypi/l/napari-gui.svg)](https://github.com/napari/napari/raw/master/LICENSE)
[![Build Status](https://api.cirrus-ci.com/github/Napari/napari-gui.svg)](https://cirrus-ci.com/napari/napari)
[![Python Version](https://img.shields.io/pypi/pyversions/napari-gui.svg)](https://python.org)
[![PyPI](https://img.shields.io/pypi/v/napari-gui.svg)](https://pypi.org/project/napari-gui)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/napari-gui.svg)](https://pypistats.org/packages/napari-gui)
[![Development Status](https://img.shields.io/pypi/status/napari-gui.svg)](https://github.com/napari/napari)

---

napari is a fast multi-dimensional image viewer for Python.

This project is in the **pre-alpha** stage; **expect breaking changes** to be made from patch to patch.

## Installation

napari can be installed on most operating systems with `pip install napari`.

### Downloading OpenGL

Windows and Linux users may need to install the [Mesa OpenGL](https://www.mesa3d.org/) library.

`vispy` provides an easily-downloadable (but out-of-date) Windows version for [64-](https://github.com/vispy/demo-data/raw/master/mesa/opengl32_mingw_64.dll) and [32-bit](https://github.com/vispy/demo-data/raw/master/mesa/opengl32_mingw_64.dll) operating systems.

Linux users can complete the installation process from the command line:

```sh
$ sudo apt update
$ sudo apt install libgl1-mesa-glx
```

## Contributing

Contributions are encouraged! Please read [our guide](https://github.com/napari/napari/blob/master/CONTRIBUTING.md) to get started.
